@@ -166,7 +166,7 @@ crudini --set --existing test.ini '' gname2 val 2>/dev/null && fail
 crudini --set test.ini section1 name val
 crudini --set --existing test.ini section1 name val2
 crudini --set --existing test.ini section1 name2 val 2>/dev/null && fail
-printf '%s\n' 'gname = val2' '' '' '[section1]' 'name = val2' > good.ini
+printf '%s\n' 'gname = val2' '' '[section1]' 'name = val2' > good.ini
 diff -u test.ini good.ini && ok || fail
 
 # --existing=section
@@ -178,7 +178,7 @@ crudini --set test.ini section1 name val
 crudini --set --existing='section' test.ini section1 name val2
 crudini --set --existing='section' test.ini section1 name2 val 2>/dev/null || fail
 printf '%s\n' 'gname = val2' 'gname2 = val' \
-       '' '' '[section1]' 'name = val2' 'name2 = val' > good.ini
+       '' '[section1]' 'name = val2' 'name2 = val' > good.ini
 diff -u test.ini good.ini && ok || fail
 
 # --get -------------------------------------------------
@@ -216,6 +216,13 @@ diff -u test.ini section1.ini && ok || fail
 # get section1 in sh format
 crudini --format=sh --get example.ini section1 > test.ini
 diff -u test.ini section1.sh && ok || fail
+# get all in sh format
+crudini --format=sh --get section1.ini > test.ini
+diff -u test.ini sections.sh && ok || fail
+# get default in sh format
+crudini --format=sh --get example.ini '' > test.ini
+printf '%s\n' 'global=supported' > good.ini
+diff -u test.ini good.ini && ok || fail
 
 # empty DEFAULT is not printed
 printf '%s\n' '[DEFAULT]' '#comment' '[section1]' > test.ini
@@ -251,7 +258,7 @@ diff -u test.ini good.ini && ok || fail
 :> test.ini
 printf '%s\n' '[DEFAULT]' 'name=val' '[section1]' |
 crudini --merge test.ini || fail
-printf '%s\n' '[DEFAULT]' 'name = val' '' '[section1]' > good.ini
+printf '%s\n' '[DEFAULT]' 'name = val' '[section1]' > good.ini
 diff -u test.ini good.ini && ok || fail
 
 :> test.ini
@@ -305,7 +312,7 @@ diff -u test.ini good.ini && ok || fail
 printf '%s\n' 'name=val1' > test.ini
 printf '%s\n' 'name=val2' |
 crudini --merge test.ini new || fail
-printf '%s\n' 'name=val1' '' '' '[new]' 'name = val2' > good.ini
+printf '%s\n' 'name=val1' '' '[new]' 'name = val2' > good.ini
 diff -u test.ini good.ini && ok || fail
 
 printf '%s\n' 'name=val1' > test.ini
@@ -351,7 +358,7 @@ printf '%s\n' '[Section1]' 'name=val2' |
 crudini --merge --existing 2>/dev/null test.ini && fail || ok
 printf '%s\n' '[Section1]' 'name=val2' |
 crudini --merge test.ini || fail
-printf '%s\n' '[section1]' 'name=val1' '' '' '[Section1]' 'name = val2' > good.ini
+printf '%s\n' '[section1]' 'name=val1' '' '[Section1]' 'name = val2' > good.ini
 diff -u test.ini good.ini && ok || fail
 
 # --del -------------------------------------------------
@@ -563,3 +570,107 @@ diff -u <(crudini --output=- --ini-options=nospace \
 diff -u <(crudini --output=- --ini-options=nospace \
           --set nospace-in.ini '' new val) \
         nospace-out.ini && ok || fail
+
+# Test multi operation
+# - Multiple set
+printf '%s\n' '' 'param1=?' 'param2=?' > file.conf
+printf '%s\n' '' 'param1=1' 'param2=2' > good.conf
+crudini --set file.conf '' param1 1 \
+        --set file.conf '' param2 2 || fail
+diff -u good.conf file.conf && ok || fail
+rm file.conf good.conf
+
+# - Multiple get
+printf '%s\n' 'param1=1' 'param2=2' > file.conf
+crudini --get file.conf '' param1 \
+        --get file.conf '' param2 \
+        --format=sh > out.conf || fail
+diff -u out.conf file.conf && ok || fail
+rm file.conf out.conf
+
+# - Mixed set / del
+printf '%s\n' '' 'param1=?' 'param2=?' > file.conf
+printf '%s\n' ''            'param2=2' > good.conf
+crudini --del file.conf '' param1   \
+        --set file.conf '' param2 2 || fail
+diff -u good.conf file.conf && ok || fail
+rm file.conf good.conf
+
+# - Mixed set / del with non existing file
+printf '%s\n' 'param1 = ' > good.conf
+crudini --set file.conf '' param1   \
+        --del file.conf '' param3 || fail
+diff -u good.conf file.conf && ok || fail
+rm file.conf good.conf
+
+# - Mixed set / get not allowed
+crudini --set file.conf '' param1   \
+        --get file.conf '' param1  2>/dev/null && fail || ok
+
+# - Multiple files not allowed
+printf '%s\n' '[section]' > file1.conf
+printf '%s\n' '[section]' > file2.conf
+crudini --del file1.conf section --del file2.conf section 2>/dev/null \
+  && fail || ok
+rm -f file1.conf file2.conf
+
+# - Multiple --merge not allowed
+crudini --merge file.conf --merge file.conf < /dev/null 2>/dev/null \
+  && fail || ok
+rm -f file.conf
+
+# - Interspersed options supported
+printf '%s\n' 'param1=1' 'param2=2' > good.conf
+crudini --set file.conf '' param1 1  \
+        --ini-options nospace \
+        --set file.conf '' param2 2 || fail
+diff -u good.conf file.conf && ok || fail
+rm file.conf good.conf
+
+# - Conflicting DEFAULT section specs not allowed
+crudini --set file.conf '' param1 value \
+        --set file.conf DEFAULT param2 value 2>/dev/null \
+  && fail || ok
+crudini --set file.conf DEFAULT param1 value \
+        --set file.conf '' param2 value 2>/dev/null \
+  && fail || ok
+rm -f file.conf
+
+# Test indentation support
+# - --get indented
+printf '  %s\n' '[section]' 'param1=1' > file.conf
+crudini --ini-options=ignoreindent \
+        --get file.conf >/dev/null && ok || fail
+
+# - --set maintaining indented
+printf '  %s\n' '[section]' 'param1=a' > good.conf
+crudini --ini-options=ignoreindent \
+        --set file.conf section param1 a && ok || fail
+diff -u good.conf file.conf && ok || fail
+
+# - --set copying indentation
+printf '  %s\n' '[section]' 'param1=a' 'param2=b' > good.conf
+crudini --ini-options=ignoreindent,nospace \
+        --set file.conf section param2 b && ok || fail
+diff -u good.conf file.conf && ok || fail
+
+# - --set new indentation for param (on new section)
+printf '%s\n' '[section]' '  param1 = a' > good.conf
+rm -f file.conf
+crudini --ini-options=ignoreindent \
+        --set file.conf section '  param1' a && ok || fail
+diff -u good.conf file.conf && ok || fail
+
+# - --set copying indentation from param
+printf '%s\n' '[section]' '  param1 = a' '  param2 = b' > good.conf
+crudini --ini-options=ignoreindent \
+        --set file.conf section 'param2' b && ok || fail
+diff -u good.conf file.conf && ok || fail
+
+# - --set new indentation for param (on new default section)
+printf '%s\n' '  param1 = a' > good.conf
+rm -f file.conf
+crudini --ini-options=ignoreindent \
+        --set file.conf '' '  param1' a && ok || fail
+diff -u good.conf file.conf && ok || fail
+rm file.conf good.conf
